#
# spec file for package SDL_image
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           SDL_image
%define lname	libSDL_image-1_2-0
Version:        1.2.12+hg695
Release:        1.24
Summary:        SDL image loading library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/X11
URL:            https://libsdl.org/projects/SDL_image/release-1.2.html

#Hg-Clone:	http://hg.libsdl.org/SDL_image/
Source:         %name-%version.tar.xz
Source3:        baselibs.conf
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(sdl)

%description
This is a simple library to load images of various formats as SDL
surfaces. This library supports the BMP, PPM, PCX, GIF, JPEG, PNG,
TIFF and WEBP formats.

%package -n %lname
Summary:        Simple DirectMedia Layer – Image loading library
Group:          System/Libraries
Provides:       SDL_image = %version-%release
Obsoletes:      SDL_image < %version-%release

%description -n %lname
This is a simple library to load images of various formats as SDL
surfaces. This library supports the BMP, PPM, PCX, GIF, JPEG, PNG,
TIFF and WEBP formats.

%package -n libSDL_image-devel
Summary:        Libraries, includes and more to develop SDL_image applications
Group:          Development/Libraries/X11
Requires:       %lname = %{version}
Provides:       SDL_image-devel = %version-%release
Obsoletes:      SDL_image-devel < %version-%release

%description -n libSDL_image-devel
This is a simple library to load images of various formats as SDL
surfaces. This library supports the BMP, PPM, PCX, GIF, JPEG, PNG,
TIFF and WEBP formats.

%prep
%autosetup -p1

%build
%configure --disable-png-shared --disable-jpg-shared --disable-tif-shared \
	--disable-webp-shared --disable-static
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING
%_libdir/libSDL_image-1*.so.*

%files -n libSDL_image-devel
%doc CHANGES README
%_includedir/SDL/
%_libdir/libSDL_image.so
%_libdir/pkgconfig/SDL_image.pc

%changelog
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 1.2.12+hg695
  * Fixed TALOS-2019-0821 CVE-2019-5052
  * Fixed TALOS-2019-0841 CVE-2019-5057 boo#1143763
  * Fixed TALOS-2019-0842 CVE-2019-5058 boo#1143764
  * Fixed TALOS-2019-0843 CVE-2019-5059 boo#1143766
  * Fixed TALOS-2019-0844 CVE-2019-5060 boo#1143768
  * Fixed CVE-2019-7635
  * Fixed CVE-2019-13616 boo#1141844
- Drop CVE-2019-13616.patch (merged)
* Thu Aug 22 2019 Michael Gorse <mgorse@suse.com>
- Add CVE-2019-13616.patch: fix heap buffer overflow when reading
  a crafted bmp file (boo#1141844 CVE-2019-13616).
* Thu Jan  8 2015 jengelh@inai.de
- Improve package summary and description. Drop --with-pic which
  is enabled implicitly anyway, remove redundant Requires.
* Tue Aug 13 2013 jengelh@inai.de
- Some metadata spruce-up: add current URLs, softer wildcarding
  in the files list
- Enable WEBP support
* Thu Jan  3 2013 crrodriguez@opensuse.org
- Disable dynamic loading of common libraries, this
  is a bad idea to beging with.
- Cleanup buildRequires. metpackage xorg-x11-devel is not required
* Wed Aug 29 2012 pgajdos@suse.com
- updated to 1.2.12:
  * Fixed regression in 1.2.11 loading 8-bit PNG images with libpng
  * Fixed loading 8-bit PNG images on Mac OS X
  * SDL_image is now under the zlib license
  * Added WEBP image support
  * Fixed compiling with libpng 1.4
  * Added Android.mk to build on the Android platform
  * Fixed loading HAM6 images with stencil mask
  * Fixed bug loading 15 and 16 bit BMP images
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Aug  1 2011 jengelh@medozas.de
- Update baselibs.conf to also ship libSDL_image-devel-32bit
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Mon Dec 21 2009 prusnak@suse.cz
- updated to 1.2.10
  * Fixed bug loading multiple images
  * Fixed checking for IMG_Init() return value in image loaders
  * Added support for uncompressed PCX files
  * Added IMG_Init()/IMG_Quit() to prevent constantly loading and unloading DLLs
  * Added support for ICO and CUR image files
* Sat Dec 19 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Oct  7 2009 prusnak@suse.cz
- fix provides and obsoletes [bnc#544957]
* Fri May 29 2009 prusnak@suse.cz
- removed VisualC.zip, Watcom-OS2.zip, Xcode.tar.gz from upstream
  tarball [bnc#508084]
* Wed May 20 2009 prusnak@suse.cz
- follow Shared Library Policy
* Tue May 19 2009 prusnak@suse.cz
- updated to 2.1.7
  * Fixed buffer overflow in BMP loading code
  * Fixed buffer overflow in GIF loading code
- removed obsoleted patches:
  * gif-overflow.patch (mainline)
  * lbm-overflow.patch (mainline)
* Fri Feb 27 2009 crrodriguez@suse.de
- remove static libraries and "la" files, useless without
  SDL static libraries too.
- fix -devel package dependencies.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 29 2008 prusnak@suse.cz
- fix buffer overflow in LBM code (lbm-overflow.patch) [#355864]
* Fri Jan 25 2008 prusnak@suse.cz
- fix buffer overflow in GIF code (gif-overflow.patch) [#355864]
* Sun Dec 16 2007 sndirsch@suse.de
- fixed BuildRequires for SUSE < 10.2
* Wed Jul 25 2007 prusnak@suse.cz
- updated to 1.2.6
  * PNG and TIFF images are correctly identified even if dynamic
    libraries to load them aren't available
  * fixed loading of TIFF images using libtiff
  * fixed static linking with libjpeg
  * fixed crash in IMG_ReadXPMFromArray()
- dropped obsolete patch:
  * xcfinc.diff (included in update)
* Sun Jul 22 2007 aj@suse.de
- Cleanup build requires.
* Fri Mar  2 2007 prusnak@suse.cz
- cleaned specfile
* Wed Nov  8 2006 prusnak@suse.cz
- increment moved outside of assignement [#218752]
* Fri Sep 29 2006 schwab@suse.de
- Require libtiff-devel for SDL_image-devel.
* Tue Sep 12 2006 nadvornik@suse.cz
- updated to 1.2.5:
  * Added support for dynamically loading libjpeg, libpng, and libtiff.
  * Added gcc-fat.sh for generating Universal binaries on Mac OS X
  * Added support for XV thumbnail images
  * Added support for 32-bit BMP files with alpha
- fixed requires of devel subpackage [#192736]
* Fri Mar 10 2006 bk@suse.de
- SDL_image-devel: add libstdc++, gcc and gpm to Requires (.la check)
* Mon Jan 30 2006 coolo@suse.de
- fixing BuildRequires to include png support
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jul 19 2005 nadvornik@suse.cz
- updated to 1.2.4
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Fri Jul 25 2003 nadvornik@suse.cz
- update to 1.2.3
* Wed Jul  3 2002 nadvornik@suse.cz
- updated to 1.2.2
* Tue Jun 11 2002 meissner@suse.de
- regenerate auto files, removed acinclude.m4 (which only contains
  SDL.m4 and libtool.m4).
* Fri May 10 2002 ro@suse.de
- libdir fixed
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Jan 22 2002 ro@suse.de
- changed neededforbuild <kdelibs-artsd> to <kdelibs3-artsd>
* Tue Jan  8 2002 nadvornik@suse.cz
- updated to 1.2.1:
  - added LBM format
  - fixed transparent GIF and PNG
* Wed Aug  8 2001 uli@suse.de
- fixed neededforbuild wrt SDL renaming
* Wed Jun 20 2001 nadvornik@suse.cz
- added kdelibs and kdelibs-devel to neededforbuild
* Thu Apr 12 2001 nadvornik@suse.cz
- update to 1.2.0
* Mon Mar 26 2001 ro@suse.de
- changed neededforbuild <sdl> to <sdl sdl-devel>
* Mon Feb 19 2001 uli@suse.de
- added alsa* to neededforbuild (needed by new SDL)
* Tue Dec  5 2000 nadvornik@suse.cz
- added suse_update_config
* Tue Nov 28 2000 nadvornik@suse.cz
- new package
